# Changelog

## [0.11.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.10.2...v0.11.0) (2026-03-07)


### Features

* **pyproject:** update bussdcc dependency to v0.33.0 ([0766304](https://github.com/jbussdieker/bussdcc-hardware/commit/076630465d10dac47a88b19ca05586ce0947fb82))

## [0.10.2](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.10.1...v0.10.2) (2026-03-06)


### Bug Fixes

* **pyproject:** update bussdcc dependency to v0.32.2 ([8c5604c](https://github.com/jbussdieker/bussdcc-hardware/commit/8c5604c2d81fa0d20085fe2e356731ccc8114356))

## [0.10.1](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.10.0...v0.10.1) (2026-03-06)


### Bug Fixes

* **pyproject:** update bussdcc dependency to v0.32.1 ([82505bf](https://github.com/jbussdieker/bussdcc-hardware/commit/82505bf55f403bb5e81bf5c88dc685baa1b927b3))

## [0.10.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.9.0...v0.10.0) (2026-03-06)


### Features

* **pyproject:** update bussdcc dependency to v0.32.0 ([0eb5622](https://github.com/jbussdieker/bussdcc-hardware/commit/0eb56228e2b6a2d9b3fa6cecaeb19ddf3445b346))

## [0.9.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.8.0...v0.9.0) (2026-03-05)


### Features

* **pyproject:** update bussdcc dependency version ([efa4e04](https://github.com/jbussdieker/bussdcc-hardware/commit/efa4e042cd7262579f42e3dce3739c1f8934658a))

## [0.8.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.7.0...v0.8.0) (2026-03-04)


### Features

* **pyproject:** update dependencies and entry points ([c8ffeb7](https://github.com/jbussdieker/bussdcc-hardware/commit/c8ffeb7f3853daad193756d8bb7ab90a1aa7be5b))

## [0.7.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.6.0...v0.7.0) (2026-03-04)


### Features

* **device, bus:** update initialization to use config dictionaries ([5d56ba5](https://github.com/jbussdieker/bussdcc-hardware/commit/5d56ba5d0396a0e3a54a1bcd444cd91f27e8a48a))

## [0.6.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.5.0...v0.6.0) (2026-03-04)


### Features

* **bus, device:** add VideoBus and W1Bus support ([9c03d48](https://github.com/jbussdieker/bussdcc-hardware/commit/9c03d48c73d2c64199a5b8eb09f1ae48f7092975))
* **gpio, relay, ds18b20:** add GPIO bus and relay device support ([a6858b2](https://github.com/jbussdieker/bussdcc-hardware/commit/a6858b2e96aa6d13d65806efa25cd0bf75b85133))

## [0.5.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.4.0...v0.5.0) (2026-03-04)


### Features

* **pyproject:** add entry points for hardware components ([303804f](https://github.com/jbussdieker/bussdcc-hardware/commit/303804f25cc5ec4be0361108a89a07d326139000))

## [0.4.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.3.0...v0.4.0) (2026-03-03)


### Features

* **ds18b20:** add DS18B20 temperature sensor support ([f5c567b](https://github.com/jbussdieker/bussdcc-hardware/commit/f5c567b7aacf3d9eb92f156e3f04aae5c8f9c798))
* **usb_camera:** add support for USB camera integration ([a321d8a](https://github.com/jbussdieker/bussdcc-hardware/commit/a321d8a5fd34eef1d50ec74bffcbfa0d09eddd7d))

## [0.3.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.2.0...v0.3.0) (2026-03-03)


### Features

* **deps:** update bussdcc to version 0.28.0 ([423176c](https://github.com/jbussdieker/bussdcc-hardware/commit/423176cd9a5c4d90aa6acd27b086604d9d5fd46d))

## [0.2.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.1.0...v0.2.0) (2026-03-03)


### Features

* **pump:** add Pump device support ([2858dfb](https://github.com/jbussdieker/bussdcc-hardware/commit/2858dfb41426a8ecdd1394a5b6b2924b797944ce))

## 0.1.0 (2026-03-02)


### Features

* **i2c:** add I2CBus and NAU7802 device support ([12c78df](https://github.com/jbussdieker/bussdcc-hardware/commit/12c78dfcf0d715f4c2cc5aee57e03df285483f5a))
* initial commit ([01b3136](https://github.com/jbussdieker/bussdcc-hardware/commit/01b313647497bffa5c14babe7bb0801c9d082cf0))


### Documentation

* **readme:** expand README with project concepts ([ee73fc1](https://github.com/jbussdieker/bussdcc-hardware/commit/ee73fc17cbfd46a17021e3678108df9681922541))
